==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCFavorite/Message/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../util/dateTime'
import Scroll from 'react-scroller-plugin'
import 'react-scroller-plugin/lib/scroll.css'
import ImgView from 'kara-module-img-view'
import Modal from 'react-modal-plugin'
import tost from "kara-module-tost";
import 'kara-module-img-view/lib/index.css'
import FileComponent from '../All/fileComponent/index'
import ImgComponent from '../All/imgComponent/index'
import TxtComponent from '../All/textComponent/index'
import LinkComponent from '../All/linkComponent/index'
@inject('FavoriteStore','ConfigStore')

@observer
class KaraMessage extends Component{
  constructor(props) {
    super(props)
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.messageList.pageNo + 1
    if(pn <= this.props.FavoriteStore.messageList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, pn)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  componentDidMount(){
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: this.props.FavoriteStore.messageList.pageNo
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  getDomByDataType= () => {
    const {lang} = this.props
   return this.props.FavoriteStore.messageList.result.map((i,k)=>{
     if(i.type === 'PLAIN_MESSAGE'){ //普通文本消息
      return <TxtComponent key={k} fileAttr={i} fromPage='message' lang={lang}
                           httpAgent={this.props.ConfigStore.config.httpAgent}
      cancelImFavorite={this.props.FavoriteStore.cancelImFavorite} 
      cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
     }
     else if (i.type === 'EVENT_MESSAGE'){ //文件消息
      if(i.fileType === 'rar' || i.fileType === 'psd' || 
      i.fileType === 'ppt'|| i.fileType === 'pptx'|| 
      i.fileType === 'xls'|| i.fileType === 'xlsx'|| 
      i.fileType === 'doc'|| i.fileType === 'docx' ){
        return <FileComponent key={k} fileAttr={i} fromPage='message' contentRef={this.props.contentRef} lang={lang}
                              httpAgent={this.props.ConfigStore.config.httpAgent}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite} 
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite} />
      }
      else if(i.fileType === 'jpg'){
        return <ImgComponent key={k} fileAttr={i} fromPage='message' contentRef={this.props.contentRef} imgViewList={this.props.FavoriteStore.imgViewList} lang={lang}
                             httpAgent={this.props.ConfigStore.config.httpAgent}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      }
     }
     else{ // 富文本消息
        return <LinkComponent key={k} fileAttr={i} fromPage='message' lang={lang}
                              httpAgent={this.props.ConfigStore.config.httpAgent}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite} 
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
     }
    })
  }
  render(){
    if(this.props.FavoriteStore.messageList.result.length <= 0) {
      return null
    }
    return (
      <div className={css.KaraMessage} ref={this.contentRef}>
      <Scroll onScrollBottom={this.onBottom}>
      {this.getDomByDataType()}
      </Scroll>
      </div>
    )
  }
}

export default KaraMessage

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCFavorite/Message/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import tost from "kara-module-tost";
import 'kara-module-img-view/lib/index.css'
import FileComponent from '../All/fileComponent/index'
import ImgComponent from '../All/imgComponent/index'
import TxtComponent from '../All/textComponent/index'
import LinkComponent from '../All/linkComponent/index'
@inject('FavoriteStore','ConfigStore')

@observer
class KaraMessage extends Component{
  constructor(props) {
    super(props)
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.messageList.pageNo + 1
    if(pn <= this.props.FavoriteStore.messageList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, pn)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  componentDidMount(){
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: this.props.FavoriteStore.messageList.pageNo
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  getDomByDataType= () => {
    const {ConfigStore,lang} = this.props
    const {karaui,httpAgent} = ConfigStore.config
   return this.props.FavoriteStore.messageList.result.map((i,k)=>{
     if(i.type === 'PLAIN_MESSAGE'){ //普通文本消息
      return <TxtComponent key={k} fileAttr={i} fromPage='message' lang={lang}
                           httpAgent={this.props.ConfigStore.config.httpAgent}
      cancelImFavorite={this.props.FavoriteStore.cancelImFavorite} 
      cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
     }
     else if (i.type === 'EVENT_MESSAGE'){ //文件消息
      if(i.fileType === 'rar' || i.fileType === 'psd' || 
      i.fileType === 'ppt'|| i.fileType === 'pptx'|| 
      i.fileType === 'xls'|| i.fileType === 'xlsx'|| 
      i.fileType === 'doc'|| i.fileType === 'docx' ){
        return <FileComponent
          key={k}
          fileAttr={i}
          fromPage='message'
          contentRef={this.props.contentRef}
          lang={lang}
          karaui={karaui}
          httpAgent={httpAgent}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite} />
      }
      else if(i.fileType === 'jpg'){
        return <ImgComponent
          key={k}
          fileAttr={i}
          fromPage='message'
          contentRef={this.props.contentRef}
          imgViewList={this.props.FavoriteStore.imgViewList}
          lang={lang}
          karaui={karaui}
          httpAgent={httpAgent}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      }
     }
     else{ // 富文本消息
        return <LinkComponent
          key={k}
          fileAttr={i}
          fromPage='message'
          lang={lang}
          karaui={karaui}
          httpAgent={httpAgent}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
     }
    })
  }
  render(){
    if(this.props.FavoriteStore.messageList.result.length <= 0) {
      return null
    }
    const {ConfigStore,FavoriteStore} = this.props
    const {karaui:{Scroll}} = ConfigStore.config
    return (
      <div className={css.KaraMessage} ref={this.contentRef}>
      <Scroll onScrollBottom={this.onBottom}>
      {this.getDomByDataType()}
      </Scroll>
      </div>
    )
  }
}

export default KaraMessage
